==> react-native-cometchat-calling-component-3.0.1.tgz: package/CallingComponentStyles.js <==
import { StyleSheet, Dimensions } from "react-native";
const { height, width } = Dimensions.get("screen");

const styles = StyleSheet.create({
  lt_control_container: {
    display: "flex",
    width: "100%",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    flexWrap: "wrap",
    height: height * 0.12,
    backgroundColor: "rgba(46, 47, 48, 0.5)",
    // position: "absolute",
    // bottom: 17,
    // zIndex: 5,
  },
  container_background: {
    display: "flex",
    width: "95%",
    height: "100%",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    flexWrap: "wrap",
    // position: "absolute",
    // bottom: 0,
    zIndex: 2,
    opacity: 0.5,
    borderRadius: 20,
    margin: 10,
    backgroundColor: "#2e2f30",
  },
  container_people: {
    display: "flex",
    width: "80%",
    height: "60%",
    marginTop: 110,
    marginRight: 10,
    flexDirection: "column",
    flexWrap: "wrap",
    position: "absolute",
    zIndex: 2,
    right: 0,
    borderRadius: 10,
    backgroundColor: "#FFF",
  },
  container_thum_list: {
    display: "flex",
    width: "28%",
    height: "75%",
    flexDirection: "column",
    flexWrap: "wrap",
    position: "absolute",
    zIndex: 2,
    right: 0,
  },
  item: {
    padding: 15,
    fontSize: 18,
    height: 70,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
  },
  item_pinned: {
    padding: 15,
    fontSize: 18,
    height: 70,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    opacity: 0.5,
    backgroundColor: "#f66301",
  },
  container: Platform.OS === "ios" ? { zIndex: 2 } : {},
  lt_control_icon: { width: 25, height: 25 },
  lt_button: {
    width: 55,
    height: 55,
    margin: 5,
    backgroundColor: "#4d4c4f",
    borderRadius: 50,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button: {
    width: 20,
    height: 20,
    margin: 5,
    backgroundColor: "#c0c0c0",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button_red: {
    width: 35,
    height: 35,
    margin: 5,
    backgroundColor: "#EB4E3D",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button_blue: {
    width: 35,
    height: 35,
    margin: 5,
    backgroundColor: "#84aeff",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  button_container: {
    alignItems: "center",
    justifyContent: "center",
    margin: 2,
    opacity: 0.7,
  },
  color_white: { color: "#fff" },
  full_height_width: { height: "100%", width: "100%" },
  mainVideoAvatarMainView: {
    height: "100%",
    width: "100%",
    alignItems: "center",
    justifyContent: "center",
    flexDirection: "column",
  },
  mainVideoName: { fontSize: 18, color: "#fff", padding: 20 },
  zero_height_width: { height: "0%", width: "0%" },
  main_video_video_track_view: {
    flex: 1,
    height: "100%",
    width: "100%",
    justifyContent: "center",
    alignItems: "center",
  },
  main_video_track_name: {
    color: "#fff",
    fontSize: 18,
    fontWeight: "bold",
    position: "absolute",
    bottom: 5,
    left: 5,
    elevation: 10,
  },
  user_item_pinned: {
    padding: 15,
    fontSize: 18,
    height: 70,
    marginStart: 10,
    marginRight: 10,
    marginBottom: 10,
    borderRadius: 10,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    backgroundColor: "#e5e5e5",
  },
  user_item_user_name: { fontSize: 18, color: "#000", marginStart: 10 },
  user_item_icon_container: {
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    position: "absolute",
    right: 10,
  },
  user_item_icons: { width: 15, height: 15 },
  user_list_network_container: { position: "absolute", bottom: 6, right: 10 },
  user_list_network_icon: { width: 10, height: 10, borderRadius: 50 },
  user_list_main_touchable: { zIndex: 10, elevation: 5 },
  user_list_user_name: {
    fontSize: 18,
    color: "#fff",
    padding: 5,
    position: "absolute",
    top: 0,
    left: 0,
    elevation: 5,
    zIndex: 5,
  },
  user_list_icon_container: {
    justifyContent: "flex-start",
    alignItems: "center",
    position: "absolute",
    right: 5,
    top: 5,
    zIndex: 5,
    elevation: 5,
  },
  user_list_avatar_name: { fontSize: 18, color: "#fff", padding: 5 },
  mainContainer: { height: "100%", width: "100%", backgroundColor: "#2E2F30" },
  video_container: { height: "88%" },
});

export default styles;

==> react-native-cometchat-calling-component-3.0.3.tgz: package/CallingComponentStyles.js <==
import { StyleSheet, Dimensions } from "react-native";
const { height, width } = Dimensions.get("screen");

const styles = StyleSheet.create({
  lt_control_container: {
    display: "flex",
    width: "100%",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    flexWrap: "wrap",
    height: height * 0.12,
    backgroundColor: "rgba(46, 47, 48, 0.5)",
    // position: "absolute",
    // bottom: 17,
    // zIndex: 5,
  },
  container_background: {
    display: "flex",
    width: "95%",
    height: "100%",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    flexWrap: "wrap",
    // position: "absolute",
    // bottom: 0,
    zIndex: 2,
    opacity: 0.5,
    borderRadius: 20,
    margin: 10,
    backgroundColor: "#2e2f30",
  },
  container_people: {
    display: "flex",
    width: "80%",
    height: "60%",
    marginTop: 110,
    marginRight: 10,
    flexDirection: "column",
    flexWrap: "wrap",
    position: "absolute",
    zIndex: 2,
    right: 0,
    borderRadius: 10,
    backgroundColor: "#FFF",
  },
  container_thum_list: {
    display: "flex",
    width: "28%",
    height: "75%",
    flexDirection: "column",
    flexWrap: "wrap",
    position: "absolute",
    zIndex: 2,
    right: 0,
  },
  item: {
    padding: 15,
    fontSize: 18,
    height: 70,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
  },
  item_pinned: {
    padding: 15,
    fontSize: 18,
    height: 70,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    opacity: 0.5,
    backgroundColor: "#f66301",
  },
  container: Platform.OS === "ios" ? { zIndex: 2 } : {},
  lt_control_icon: { width: 25, height: 25 },
  lt_button: {
    width: 55,
    height: 55,
    margin: 5,
    backgroundColor: "#4d4c4f",
    borderRadius: 50,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button: {
    width: 10,
    height: 10,
    margin: 2,
    // backgroundColor: "#c0c0c0",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button_red: {
    width: 35,
    height: 35,
    margin: 5,
    backgroundColor: "#EB4E3D",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  lt_small_button_blue: {
    width: 35,
    height: 35,
    margin: 5,
    backgroundColor: "#84aeff",
    borderRadius: 20,
    alignItems: "center",
    justifyContent: "center",
  },
  button_container: {
    alignItems: "center",
    justifyContent: "center",
    margin: 2,
    opacity: 0.7,
  },
  color_white: { color: "#fff" },
  full_height_width: { height: "100%", width: "100%" },
  mainVideoAvatarMainView: {
    height: "100%",
    width: "100%",
    alignItems: "center",
    justifyContent: "center",
    flexDirection: "column",
  },
  mainVideoName: { fontSize: 18, color: "#fff", padding: 20 },
  zero_height_width: { height: "0%", width: "0%" },
  main_video_video_track_view: {
    flex: 1,
    height: "100%",
    width: "100%",
    justifyContent: "center",
    alignItems: "center",
  },
  main_video_track_name: {
    color: "#fff",
    fontSize: 18,
    fontWeight: "bold",
    position: "absolute",
    bottom: 5,
    left: 5,
    elevation: 10,
  },
  user_item_pinned: {
    padding: 15,
    fontSize: 18,
    height: 70,
    marginStart: 10,
    marginRight: 10,
    marginBottom: 10,
    borderRadius: 10,
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    backgroundColor: "#e5e5e5",
  },
  user_item_user_name: { fontSize: 18, color: "#000", marginStart: 10 },
  user_item_icon_container: {
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    position: "absolute",
    right: 10,
  },
  user_item_icons: { width: 15, height: 15 },
  user_list_network_container: { position: "absolute", bottom: 6, right: 10 },
  user_list_network_icon: { width: 10, height: 10, borderRadius: 50 },
  user_list_main_touchable: { zIndex: 10, elevation: 5 },
  user_list_user_name: {
    fontSize: 18,
    color: "#fff",
    padding: 5,
    position: "absolute",
    top: 0,
    left: 0,
    elevation: 5,
    zIndex: 5,
  },
  user_list_icon_container: {
    justifyContent: "flex-start",
    alignItems: "center",
    position: "absolute",
    left: 5,
    bottom: 5,
    zIndex: 5,
    elevation: 5,
  },
  user_list_avatar_name: { fontSize: 18, color: "#fff", padding: 5 },
  mainContainer: { height: "100%", width: "100%", backgroundColor: "#2E2F30" },
  video_container: { height: "88%" },
});

export default styles;
